.. title:: Starsim


.. include:: ../README.rst


Learn more
----------

.. grid:: 3
    :gutter: 4

    .. grid-item-card:: Tutorials
        :link: tutorials
        :link-type: doc

        An interactive tour of Starsim's key features.

    .. grid-item-card:: API reference
        :link: api/index
        :link-type: doc

        Full details on all classes and functions.

    .. grid-item-card:: What's new
        :link: whatsnew
        :link-type: doc
        
        See what's in the latest Starsim releases.


.. toctree::
   :maxdepth: 1
   :hidden:

   tutorials
   api/index
   whatsnew
   conduct
   contributing
